==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/migrate/kotlin/inputs/GetBusinessCaseOperationReportDownloadUrlPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.migrate.kotlin.inputs

import com.pulumi.azurenative.migrate.inputs.GetBusinessCaseOperationReportDownloadUrlPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property businessCaseName Business case ARM name
 * @property projectName Assessment Project Name
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 */
public data class GetBusinessCaseOperationReportDownloadUrlPlainArgs(
    public val businessCaseName: String,
    public val projectName: String,
    public val resourceGroupName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.migrate.inputs.GetBusinessCaseOperationReportDownloadUrlPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.migrate.inputs.GetBusinessCaseOperationReportDownloadUrlPlainArgs =
        com.pulumi.azurenative.migrate.inputs.GetBusinessCaseOperationReportDownloadUrlPlainArgs.builder()
            .businessCaseName(businessCaseName.let({ args0 -> args0 }))
            .projectName(projectName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetBusinessCaseOperationReportDownloadUrlPlainArgs].
 */
@PulumiTagMarker
public class GetBusinessCaseOperationReportDownloadUrlPlainArgsBuilder internal constructor() {
    private var businessCaseName: String? = null

    private var projectName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value Business case ARM name
     */
    @JvmName("fdijvvgvdxywroxf")
    public suspend fun businessCaseName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.businessCaseName = mapped
    }

    /**
     * @param value Assessment Project Name
     */
    @JvmName("bfkcjnfvgehbxitr")
    public suspend fun projectName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.projectName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("baychkfvjwewqrmk")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetBusinessCaseOperationReportDownloadUrlPlainArgs =
        GetBusinessCaseOperationReportDownloadUrlPlainArgs(
            businessCaseName = businessCaseName ?: throw PulumiNullFieldException("businessCaseName"),
            projectName = projectName ?: throw PulumiNullFieldException("projectName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/migrate/kotlin/inputs/GetBusinessCaseOperationReportDownloadUrlPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.migrate.kotlin.inputs

import com.pulumi.azurenative.migrate.inputs.GetBusinessCaseOperationReportDownloadUrlPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property businessCaseName Business case ARM name
 * @property projectName Assessment Project Name
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 */
public data class GetBusinessCaseOperationReportDownloadUrlPlainArgs(
    public val businessCaseName: String,
    public val projectName: String,
    public val resourceGroupName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.migrate.inputs.GetBusinessCaseOperationReportDownloadUrlPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.migrate.inputs.GetBusinessCaseOperationReportDownloadUrlPlainArgs =
        com.pulumi.azurenative.migrate.inputs.GetBusinessCaseOperationReportDownloadUrlPlainArgs.builder()
            .businessCaseName(businessCaseName.let({ args0 -> args0 }))
            .projectName(projectName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetBusinessCaseOperationReportDownloadUrlPlainArgs].
 */
@PulumiTagMarker
public class GetBusinessCaseOperationReportDownloadUrlPlainArgsBuilder internal constructor() {
    private var businessCaseName: String? = null

    private var projectName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value Business case ARM name
     */
    @JvmName("rngsmiihwfstkiro")
    public suspend fun businessCaseName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.businessCaseName = mapped
    }

    /**
     * @param value Assessment Project Name
     */
    @JvmName("bwyqmkuhhhuojkfc")
    public suspend fun projectName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.projectName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("sxxtsotyqqthkbcb")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetBusinessCaseOperationReportDownloadUrlPlainArgs =
        GetBusinessCaseOperationReportDownloadUrlPlainArgs(
            businessCaseName = businessCaseName ?: throw PulumiNullFieldException("businessCaseName"),
            projectName = projectName ?: throw PulumiNullFieldException("projectName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        )
}
